@@ -3,9 +3,9 @@ package com.unciv.logic.city
 import com.badlogic.gdx.math.Vector2
 import com.unciv.GUI
 import com.unciv.logic.IsPartOfGameInfoSerialization
+import com.unciv.logic.city.managers.CityConquestFunctions
 import com.unciv.logic.city.managers.CityEspionageManager
 import com.unciv.logic.city.managers.CityExpansionManager
-import com.unciv.logic.city.managers.CityInfoConquestFunctions
 import com.unciv.logic.city.managers.CityPopulationManager
 import com.unciv.logic.city.managers.CityReligionManager
 import com.unciv.logic.city.managers.SpyFleeReason
@@ -254,6 +254,16 @@ class City : IsPartOfGameInfoSerialization {
         return cityResources
     }
 
+    /** Gets the number of resources available to this city
+     * Accommodates both city-wide and civ-wide resources */
+    fun getResourceAmount(resourceName: String): Int {
+        val resource = getRuleset().tileResources[resourceName] ?: return 0
+
+        if (resource.hasUnique(UniqueType.CityResource))
+            return getCityResources().asSequence().filter { it.resource == resource }.sumOf { it.amount }
+        return civ.getResourceAmount(resourceName)
+    }
+
     private fun getTileResourceAmount(tile: Tile): Int {
         if (tile.resource == null) return 0
         if (!tile.providesResources(civ)) return 0
@@ -457,9 +467,7 @@ class City : IsPartOfGameInfoSerialization {
 
         // Move the capital if destroyed (by a nuke or by razing)
         // Must be before removing existing capital because we may be annexing a puppet which means city stats update - see #8337
-        if (isCapital() && civ.cities.size > 1) {
-            civ.moveCapitalToNextLargest()
-        }
+        if (isCapital()) civ.moveCapitalToNextLargest()
 
         civ.cities = civ.cities.toMutableList().apply { remove(this@City) }
         getCenterTile().changeImprovement("City ruins")
@@ -486,18 +494,18 @@ class City : IsPartOfGameInfoSerialization {
         civ.gameInfo.cityDistances.setDirty()
     }
 
-    fun annexCity() = CityInfoConquestFunctions(this).annexCity()
+    fun annexCity() = CityConquestFunctions(this).annexCity()
 
     /** This happens when we either puppet OR annex, basically whenever we conquer a city and don't liberate it */
     fun puppetCity(conqueringCiv: Civilization) =
-        CityInfoConquestFunctions(this).puppetCity(conqueringCiv)
+        CityConquestFunctions(this).puppetCity(conqueringCiv)
 
     /* Liberating is returning a city to its founder - makes you LOSE warmongering points **/
     fun liberateCity(conqueringCiv: Civilization) =
-        CityInfoConquestFunctions(this).liberateCity(conqueringCiv)
+        CityConquestFunctions(this).liberateCity(conqueringCiv)
 
     fun moveToCiv(newCivInfo: Civilization) =
-        CityInfoConquestFunctions(this).moveToCiv(newCivInfo)
+        CityConquestFunctions(this).moveToCiv(newCivInfo)
 
     internal fun tryUpdateRoadStatus() {
         if (getCenterTile().roadStatus == RoadStatus.None) {
