@@ -320,7 +320,8 @@ class Civilization : IsPartOfGameInfoSerialization {
     fun knows(otherCivName: String) = diplomacy.containsKey(otherCivName)
     fun knows(otherCiv: Civilization) = knows(otherCiv.civName)
 
-    fun getCapital() = cities.firstOrNull { it.isCapital() }
+    fun getCapital(firstCityIfNoCapital: Boolean = false) = cities.firstOrNull { it.isCapital() } ?:
+        if (firstCityIfNoCapital) cities.firstOrNull() else null
     fun isHuman() = playerType == PlayerType.Human
     fun isAI() = playerType == PlayerType.AI
     fun isOneCityChallenger() = playerType == PlayerType.Human && gameInfo.gameParameters.oneCityChallenge
@@ -423,6 +424,13 @@ class Civilization : IsPartOfGameInfoSerialization {
         return hashMap
     }
 
+    /** Gets the number of resources available to this city
+     * Does not include city-wide resources
+     * Returns 0 for undefined resources */
+    fun getResourceAmount(resourceName:String): Int {
+        return getCivResourcesByName()[resourceName] ?: 0
+    }
+
     fun getResourceModifier(resource: TileResource): Float {
         var resourceModifier = 1f
         for (unique in getMatchingUniques(UniqueType.DoubleResourceProduced))
@@ -436,7 +444,7 @@ class Civilization : IsPartOfGameInfoSerialization {
         return resourceModifier
     }
 
-    fun hasResource(resourceName: String): Boolean = getCivResourcesByName()[resourceName]!! > 0
+    fun hasResource(resourceName: String): Boolean = getResourceAmount(resourceName) > 0
 
     fun hasUnique(uniqueType: UniqueType, stateForConditionals: StateForConditionals =
         StateForConditionals(this)) = getMatchingUniques(uniqueType, stateForConditionals).any()
@@ -491,7 +499,12 @@ class Civilization : IsPartOfGameInfoSerialization {
         return tech.currentTechnology() == null && cities.isNotEmpty()
     }
 
-    fun getEquivalentBuilding(buildingName: String) = getEquivalentBuilding(gameInfo.ruleset.buildings[buildingName]!!)
+    fun getEquivalentBuilding(buildingName: String): Building {
+        val building = gameInfo.ruleset.buildings[buildingName]
+            ?: throw Exception("No building by the name of $buildingName exists!")
+        return getEquivalentBuilding(building)
+    }
+
     fun getEquivalentBuilding(baseBuilding: Building): Building {
         if (baseBuilding.replaces != null)
             return getEquivalentBuilding(baseBuilding.replaces!!)
@@ -657,15 +670,15 @@ class Civilization : IsPartOfGameInfoSerialization {
             diplomacyManager.updateHasOpenBorders()
         }
 
-        for (cityInfo in cities) {
-            cityInfo.setTransients(this) // must be before the city's setTransients because it depends on the tilemap, that comes from the currentPlayerCivInfo
+        for (city in cities) {
+            city.setTransients(this) // must be before the city's setTransients because it depends on the tilemap, that comes from the currentPlayerCivInfo
         }
 
         // Now that all tile transients have been updated, clean "worked" tiles that are not under the Civ's control
-        for (cityInfo in cities)
-            for (workedTile in cityInfo.workedTiles.toList())
+        for (city in cities)
+            for (workedTile in city.workedTiles.toList())
                 if (gameInfo.tileMap[workedTile].getOwner() != this)
-                    cityInfo.workedTiles.remove(workedTile)
+                    city.workedTiles.remove(workedTile)
 
         passThroughImpassableUnlocked = passableImpassables.isNotEmpty()
         // Cache whether this civ gets nonstandard terrain damage for performance reasons.
@@ -697,7 +710,7 @@ class Civilization : IsPartOfGameInfoSerialization {
         && gameInfo.civilizations.any { it.isMajorCiv() && !it.isDefeated() && it != this }
 
     fun diplomaticVoteForCiv(chosenCivName: String?) {
-        if (chosenCivName != null) gameInfo.diplomaticVictoryVotesCast[civName] = chosenCivName
+        gameInfo.diplomaticVictoryVotesCast[civName] = chosenCivName
     }
 
     fun shouldShowDiplomaticVotingResults() =
@@ -810,12 +823,18 @@ class Civilization : IsPartOfGameInfoSerialization {
             city.cityConstructions.addBuilding(city.capitalCityIndicator())
             city.isBeingRazed = false // stop razing the new capital if it was being razed
         }
-        oldCapital?.cityConstructions?.removeBuilding(oldCapital.capitalCityIndicator())
+        // Don't use removeBuilding, since that rebuilds uniques and can generate errors when we have no capital
+        // We're going to recalc the uniques anyway once we move it to the new civ
+        oldCapital?.cityConstructions?.builtBuildings?.remove(oldCapital.capitalCityIndicator())
     }
 
     fun moveCapitalToNextLargest() {
         val availableCities = cities.filterNot { it.isCapital() }
-        if (availableCities.none()) return
+        if (availableCities.none()) {
+            moveCapitalTo(null)
+            return
+        }
+
         var newCapital = availableCities.filterNot { it.isPuppet }.maxByOrNull { it.population.population }
 
         if (newCapital == null) { // No non-puppets, take largest puppet and annex
