@@ -10,6 +10,7 @@ import com.unciv.models.ruleset.unique.IHasUniques
 import com.unciv.models.ruleset.unique.StateForConditionals
 import com.unciv.models.ruleset.unique.Unique
 import com.unciv.models.ruleset.unique.UniqueType
+import com.unciv.models.ruleset.unit.Promotion
 import com.unciv.models.stats.INamed
 import com.unciv.models.stats.Stats
 
@@ -387,6 +388,7 @@ class RulesetValidator(val ruleset: Ruleset) {
                 if (!ruleset.unitTypes.containsKey(unitType) && (ruleset.unitTypes.isNotEmpty() || !vanillaRuleset.unitTypes.containsKey(unitType)))
                     lines.add("${promotion.name} references unit type $unitType, which does not exist!", RulesetErrorSeverity.Warning)
             checkUniques(promotion, lines, rulesetSpecific, tryFixUnknownUniques)
+            checkPromotionCircularReferences(lines)
         }
 
         for (unitType in ruleset.unitTypes.values) {
@@ -416,7 +418,7 @@ class RulesetValidator(val ruleset: Ruleset) {
                 val errors = checkUnique(
                     unique,
                     tryFixUnknownUniques,
-                    cityStateType.name,
+                    cityStateType,
                     rulesetSpecific
                 )
                 lines.addAll(errors)
@@ -426,6 +428,24 @@ class RulesetValidator(val ruleset: Ruleset) {
         return lines
     }
 
+    private fun checkPromotionCircularReferences(lines: RulesetErrorList) {
+        fun recursiveCheck(history: LinkedHashSet<Promotion>, promotion: Promotion, level: Int) {
+            if (promotion in history) {
+                lines.add("Circular Reference in Promotions: ${history.joinToString("→") { it.name }}→${promotion.name}", RulesetErrorSeverity.Warning)
+                return
+            }
+            if (level > 99) return
+            history.add(promotion)
+            for (prerequisiteName in promotion.prerequisites) {
+                val prerequisite = ruleset.unitPromotions[prerequisiteName] ?: continue
+                recursiveCheck(history.toCollection(linkedSetOf()), prerequisite, level + 1)
+            }
+        }
+        for (promotion in ruleset.unitPromotions.values) {
+            recursiveCheck(linkedSetOf(), promotion, 0)
+        }
+    }
+
 
     fun checkUniques(
         uniqueContainer: IHasUniques,
@@ -433,13 +453,11 @@ class RulesetValidator(val ruleset: Ruleset) {
         severityToReport: UniqueType.UniqueComplianceErrorSeverity,
         tryFixUnknownUniques: Boolean
     ) {
-        val name = if (uniqueContainer is INamed) uniqueContainer.name else ""
-
         for (unique in uniqueContainer.uniqueObjects) {
             val errors = checkUnique(
                 unique,
                 tryFixUnknownUniques,
-                name,
+                uniqueContainer as? INamed,
                 severityToReport
             )
             lines.addAll(errors)
@@ -449,9 +467,11 @@ class RulesetValidator(val ruleset: Ruleset) {
     fun checkUnique(
         unique: Unique,
         tryFixUnknownUniques: Boolean,
-        name: String,
+        namedObj: INamed?,
         severityToReport: UniqueType.UniqueComplianceErrorSeverity
     ): List<RulesetError> {
+        var name = namedObj?.name ?: ""
+        if (namedObj!=null && namedObj is IRulesetObject) name = "${namedObj.originRuleset}: $name"
         if (unique.type == null) {
             if (!tryFixUnknownUniques) return emptyList()
             val similarUniques = UniqueType.values().filter {
