@@ -5,13 +5,14 @@ import com.unciv.Constants
 import com.unciv.logic.civilization.managers.ReligionState
 import com.unciv.models.ruleset.BeliefType
 import com.unciv.models.translations.tr
-import com.unciv.ui.components.KeyboardBinding
+import com.unciv.ui.components.UncivTooltip.Companion.addTooltip
 import com.unciv.ui.components.extensions.disable
 import com.unciv.ui.components.extensions.enable
 import com.unciv.ui.components.extensions.isEnabled
-import com.unciv.ui.components.extensions.keyShortcuts
-import com.unciv.ui.components.extensions.onActivation
 import com.unciv.ui.components.extensions.setSize
+import com.unciv.ui.components.input.KeyboardBinding
+import com.unciv.ui.components.input.keyShortcuts
+import com.unciv.ui.components.input.onActivation
 import com.unciv.ui.images.IconTextButton
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.popups.ConfirmPopup
@@ -27,7 +28,7 @@ import com.unciv.utils.Concurrency
 import com.unciv.utils.launchOnGLThread
 
 class NextTurnButton : IconTextButton("", null, 30) {
-    private var nextTurnAction = NextTurnAction("", Color.BLACK) {}
+    private var nextTurnAction = NextTurnAction.Default
 
     init {
 //         label.setFontSize(30)
@@ -41,29 +42,33 @@ class NextTurnButton : IconTextButton("", null, 30) {
 
     fun update(worldScreen: WorldScreen) {
         nextTurnAction = getNextTurnAction(worldScreen)
+        updateButton(nextTurnAction)
+
+        isEnabled = !worldScreen.hasOpenPopups() && worldScreen.isPlayersTurn
+                && !worldScreen.waitingForAutosave && !worldScreen.isNextTurnUpdateRunning()
+
+        if (isEnabled) addTooltip(KeyboardBinding.NextTurn) else addTooltip("")
+    }
+    internal fun updateButton(nextTurnAction: NextTurnAction) {
         label.setText(nextTurnAction.text.tr())
         label.color = nextTurnAction.color
-        if (nextTurnAction.icon != null && ImageGetter.imageExists(nextTurnAction.icon!!))
+        if (nextTurnAction.icon != null && ImageGetter.imageExists(nextTurnAction.icon))
             iconCell.setActor(ImageGetter.getImage(nextTurnAction.icon).apply { setSize(30f) })
         else
             iconCell.clearActor()
         pack()
-
-        isEnabled = !worldScreen.hasOpenPopups() && worldScreen.isPlayersTurn
-                && !worldScreen.waitingForAutosave && !worldScreen.isNextTurnUpdateRunning()
     }
 
 
     private fun getNextTurnAction(worldScreen: WorldScreen): NextTurnAction {
         return when {
             worldScreen.isNextTurnUpdateRunning() ->
-                NextTurnAction("Working...", Color.GRAY, "NotificationIcons/Working") {}
+                NextTurnAction.Working
             !worldScreen.isPlayersTurn && worldScreen.gameInfo.gameParameters.isOnlineMultiplayer ->
                 NextTurnAction("Waiting for [${worldScreen.gameInfo.currentPlayerCiv}]...", Color.GRAY,
                     "NotificationIcons/Waiting") {}
             !worldScreen.isPlayersTurn && !worldScreen.gameInfo.gameParameters.isOnlineMultiplayer ->
-                NextTurnAction("Waiting for other players...",Color.GRAY,
-                    "NotificationIcons/Waiting") {}
+                NextTurnAction.Waiting
 
             worldScreen.viewingCiv.cities.any {
                 !it.isPuppet &&
@@ -157,8 +162,11 @@ class NextTurnButton : IconTextButton("", null, 30) {
                 .any { it.currentMovement > Constants.minimumMovementEpsilon && (it.isMoving() || it.isAutomated() || it.isExploring()) } ->
                 NextTurnAction("Move automated units", Color.LIGHT_GRAY,
                     "NotificationIcons/MoveAutomatedUnits") {
-                    worldScreen.viewingCiv.hasMovedAutomatedUnits = true
+                    // Don't allow double-click of 'n' to spawn 2 processes trying to automate units
+                    if (!worldScreen.isPlayersTurn) return@NextTurnAction
+
                     worldScreen.isPlayersTurn = false // Disable state changes
+                    worldScreen.viewingCiv.hasMovedAutomatedUnits = true
                     worldScreen.nextTurnButton.disable()
                     Concurrency.run("Move automated units") {
                         for (unit in worldScreen.viewingCiv.units.getCivUnits())
@@ -185,7 +193,12 @@ class NextTurnButton : IconTextButton("", null, 30) {
                 }
         }
     }
-
 }
 
-class NextTurnAction(val text: String, val color: Color, val icon: String? = null, val action: () -> Unit)
+class NextTurnAction(val text: String, val color: Color, val icon: String? = null, val action: () -> Unit) {
+    companion object Prefabs {
+        val Default = NextTurnAction("", Color.BLACK) {}
+        val Working = NextTurnAction(Constants.working, Color.GRAY, "NotificationIcons/Working") {}
+        val Waiting = NextTurnAction("Waiting for other players...",Color.GRAY, "NotificationIcons/Waiting") {}
+    }
+}
